@@ -6,15 +6,16 @@ from metainfo.exception.PackageFileNotFoundError import PackageFileNotFoundError
 
 class MetaInfo:
 
-    def __init__(self, package_name):
+    def __init__(self, package_name, default_setup_path='..'):
         self.package_name = package_name
+        self.default_setup_path = default_setup_path
         self.meta_info = self.init_environment_meta_info()
 
     def init_environment_meta_info(self) -> EnvironmentMetaInfo:
         try:
             return DeployedEnvironmentMetaInfo(self.package_name)
         except PackageFileNotFoundError:
-            return DevEnvironmentMetaInfo()
+            return DevEnvironmentMetaInfo(default_path=self.default_setup_path)
 
     def get_version(self):
         return self.meta_info.get_version()
